@@ -19,14 +19,16 @@
 // the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 // Boston, MA 02110-1301, USA.
 
+#include <KNumInput>
+
 #include <qlabel.h>
 #include <qslider.h>
 #include <qlayout.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
-#include <qspinbox.h>
 #include <qpushbutton.h>
 #include <qxml.h>
+
 //Added by qt3to4:
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -41,44 +43,61 @@ KXSRangeControl::KXSRangeControl(QWidget *parent, const QString &name,
 {
   QVBoxLayout *l = new QVBoxLayout(this);
   QLabel *label = new QLabel(mLabel, this);
-  l->add(label);
-  mSlider = new QSlider(mMinimum, mMaximum, 10, mValue, Qt::Horizontal, this);
+  l->addWidget(label);
+  mSlider = new QSlider(Qt::Horizontal, this);
+  mSlider->setMinimum(mMinimum);
+  mSlider->setMaximum(mMaximum);
+  mSlider->setPageStep(10);
+  mSlider->setValue(mValue);
   connect(mSlider, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
-  l->add(mSlider);
+  l->addWidget(mSlider);
 }
 
 KXSRangeControl::KXSRangeControl(QWidget *parent, const QString &name,
                                   const QXmlAttributes &attr )
   : QWidget(parent), KXSRangeItem(name, attr), mSlider(0), mSpinBox(0)
 {
+	// NOTE: Contexts used and assembled here have to match with contexts
+	// extracted by the PO template creation script.
+	
     if (attr.value("type") == "spinbutton" ) {
 	QHBoxLayout *hb = new QHBoxLayout(this);
 	if (!mLabel.isEmpty()) {
-	    QLabel *l = new QLabel(i18n(mLabel.toUtf8()), this);
-	    hb->add(l);
+	    QLabel *l = new QLabel(i18nc("@label:spinbox", mLabel.toUtf8()), this);
+	    hb->addWidget(l);
 	}
-	mSpinBox = new QSpinBox(mMinimum, mMaximum, 1, this);
+	mSpinBox = new KIntSpinBox(this);
+        mSpinBox->setMinimum(mMinimum);
+        mSpinBox->setMaximum(mMaximum);
+        mSpinBox->setSingleStep(1);
 	mSpinBox->setValue(mValue);
 	connect(mSpinBox, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
-	hb->add(mSpinBox);
+	hb->addWidget(mSpinBox);
     } else {
 	QString lowLabel = attr.value("_low-label");
 	QString highLabel = attr.value("_high-label");
 	QVBoxLayout *vb = new QVBoxLayout(this);
 	if (!mLabel.isEmpty()) {
-	    QLabel *l = new QLabel(i18n(mLabel.toUtf8()), this);
-	    vb->add(l);
+	    QLabel *l = new QLabel(i18nc("@label:slider", mLabel.toUtf8()), this);
+	    vb->addWidget(l);
 	}
-	QHBoxLayout *hb = new QHBoxLayout(vb);
+	QHBoxLayout *hb = new QHBoxLayout();
+        vb->addLayout(hb);
+	QString limCtxt = mLabel.isEmpty() ? QString("@item:inrange")
+	                                   : QString("@item:inrange %1").arg(mLabel);
 	if (!lowLabel.isEmpty()) {
-	    QLabel *l = new QLabel(i18n(lowLabel.toUtf8()), this);
+	    QLabel *l = new QLabel(i18nc(limCtxt.toUtf8(), lowLabel.toUtf8()), this);
 	    hb->addWidget(l);
 	}
-	mSlider = new QSlider(mMinimum, mMaximum, 10, mValue, Qt::Horizontal, this);
+	mSlider = new QSlider(Qt::Horizontal, this);
+	mSlider->setMinimum(mMinimum);
+	mSlider->setMaximum(mMaximum);
+	mSlider->setPageStep(10);
+	mSlider->setValue(mValue);
 	connect(mSlider, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
-	hb->add(mSlider);
+	hb->addWidget(mSlider);
 	if (!highLabel.isEmpty()){
-	    QLabel *l = new QLabel(i18n(highLabel.toUtf8()), this);
+	    QLabel *l = new QLabel(i18nc(limCtxt.toUtf8(), highLabel.toUtf8()), this);
 	    hb->addWidget(l);
 	}
     }
@@ -106,37 +125,51 @@ KXSDoubleRangeControl::KXSDoubleRangeControl(QWidget *parent,
 {
   QVBoxLayout *l = new QVBoxLayout(this);
   QLabel *label = new QLabel(mLabel, this);
-  l->add(label);
+  l->addWidget(label);
 
   int value = int((mValue - mMinimum) * 100 / (mMaximum - mMinimum));
 
-  mSlider = new QSlider(0, 100, 10, value, Qt::Horizontal, this);
+  mSlider = new QSlider(Qt::Horizontal, this);
+  mSlider->setMinimum(0);
+  mSlider->setMaximum(100);
+  mSlider->setPageStep(10);
+  mSlider->setValue(value);
   connect(mSlider, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
-  l->add(mSlider);
+  l->addWidget(mSlider);
 }
 
 KXSDoubleRangeControl::KXSDoubleRangeControl(QWidget *parent,
                                   const QString &name, const QXmlAttributes &attr)
   : QWidget(parent), KXSDoubleRangeItem(name, attr)
 {
+    // NOTE: Contexts used and assembled here have to match with contexts
+    // extracted by the PO template creation script.
+
     QString lowLabel = attr.value("_low-label");
     QString highLabel = attr.value("_high-label");
     QVBoxLayout *vb = new QVBoxLayout(this);
     if (!mLabel.isEmpty()) {
-	QLabel *l = new QLabel(i18n(mLabel.toUtf8()), this);
-	vb->add(l);
+	QLabel *l = new QLabel(i18nc("@label:slider", mLabel.toUtf8()), this);
+	vb->addWidget(l);
     }
-    QHBoxLayout *hb = new QHBoxLayout(vb);
+    QHBoxLayout *hb = new QHBoxLayout();
+    vb->addLayout(hb);
+    QString limCtxt = !mLabel.isEmpty() ? QString("@item:inrange %1").arg(mLabel)
+                                        : QString("@item:inrange");
     if (!lowLabel.isEmpty()) {
-	QLabel *l = new QLabel(i18n(lowLabel.toUtf8()), this);
+	QLabel *l = new QLabel(i18nc(limCtxt.toUtf8(), lowLabel.toUtf8()), this);
 	hb->addWidget(l);
     }
     int value = int((mValue - mMinimum) * 100 / (mMaximum - mMinimum));
-    mSlider = new QSlider(0, 100, 10, value, Qt::Horizontal, this);
+    mSlider = new QSlider(Qt::Horizontal, this);
+    mSlider->setMinimum(0);
+    mSlider->setMaximum(100);
+    mSlider->setPageStep(10);
+    mSlider->setValue(value);
     connect(mSlider, SIGNAL(valueChanged(int)), SLOT(slotValueChanged(int)));
-    hb->add(mSlider);
+    hb->addWidget(mSlider);
     if (!highLabel.isEmpty()){
-	QLabel *l = new QLabel(i18n(highLabel.toUtf8()), this);
+	QLabel *l = new QLabel(i18nc(limCtxt.toUtf8(), highLabel.toUtf8()), this);
 	hb->addWidget(l);
     }
 }
@@ -168,15 +201,17 @@ KXSCheckBoxControl::KXSCheckBoxControl(QWidget *parent, const QString &name,
                                       const QXmlAttributes &attr)
   : QCheckBox(parent), KXSBoolItem(name, attr)
 {
-  setText(i18n(mLabel.toUtf8()));
+  // NOTE: Contexts used and assembled here have to match with contexts
+  // extracted by the PO template creation script.
+  setText(i18nc("@option:check", mLabel.toUtf8()));
   setChecked(mValue);
   connect(this, SIGNAL(toggled(bool)), SLOT(slotToggled(bool)));
 }
 
 void KXSCheckBoxControl::slotToggled(bool state)
 {
-  mValue = state;
-  emit changed();
+    mValue = state;
+    emit changed();
 }
 
 void KXSCheckBoxControl::read(KConfig &config)
@@ -192,34 +227,42 @@ KXSDropListControl::KXSDropListControl(QWidget *parent, const QString &name,
 {
   QVBoxLayout *l = new QVBoxLayout(this);
   QLabel *label = new QLabel(mLabel, this);
-  l->add(label);
+  l->addWidget(label);
   mCombo = new QComboBox(this);
-  for(uint i=0; i < mOptions.count(); i++)
-      mCombo->insertItem( i18n(mOptions[i].toUtf8()) );
-  mCombo->setCurrentItem(mValue);
+  for(int i=0; i < mOptions.count(); i++)
+      mCombo->addItem( i18n(mOptions[i].toUtf8()) );
+  mCombo->setCurrentIndex(mValue);
   connect(mCombo, SIGNAL(activated(int)), SLOT(slotActivated(int)));
-  l->add(mCombo);
+  l->addWidget(mCombo);
 }
 
 KXSDropListControl::KXSDropListControl(QWidget *parent, const QString &name,
                                       const QXmlAttributes &attr)
   : QWidget(parent), KXSSelectItem(name, attr)
 {
+  // NOTE: Contexts used and assembled here have to match with contexts
+  // extracted by the PO template creation script.
+
   QVBoxLayout *l = new QVBoxLayout(this);
-  QString labelText = mLabel.isEmpty() ? QString():i18n(mLabel.toUtf8());
+  QString labelText = mLabel.isEmpty() ? QString():i18nc("@title:group", mLabel.toUtf8());
   QLabel *label = new QLabel(labelText, this);
-  l->add(label);
+  l->addWidget(label);
   mCombo = new QComboBox(this);
   connect(mCombo, SIGNAL(activated(int)), SLOT(slotActivated(int)));
-  l->add(mCombo);
+  l->addWidget(mCombo);
 }
 
 void KXSDropListControl::addOption(const QXmlAttributes &attr)
 {
+    // NOTE: Contexts used and assembled here have to match with contexts
+    // extracted by the PO template creation script.
+
+    QString itemCtxt = mLabel.isEmpty() ? QString("@option:radio")
+                                        : QString("@option:radio %1").arg(mLabel);
     KXSSelectItem::addOption( attr );
-    mCombo->insertItem( i18n(mOptions[mOptions.count()-1].toUtf8()) );
-    if ( (unsigned)mValue == mOptions.count()-1 )
-	mCombo->setCurrentItem(mOptions.count()-1);
+    mCombo->addItem( i18nc(itemCtxt.toUtf8(), mOptions[mOptions.count()-1].toUtf8()) );
+    if ( mValue == mOptions.count()-1 )
+	mCombo->setCurrentIndex(mOptions.count()-1);
 }
 
 void KXSDropListControl::slotActivated(int indx)
@@ -231,7 +274,7 @@ void KXSDropListControl::slotActivated(int indx)
 void KXSDropListControl::read(KConfig &config)
 {
     KXSSelectItem::read(config);
-    mCombo->setCurrentItem(mValue);
+    mCombo->setCurrentIndex(mValue);
 }
 
 //===========================================================================
@@ -241,28 +284,31 @@ KXSLineEditControl::KXSLineEditControl(QWidget *parent, const QString &name,
 {
   QVBoxLayout *l = new QVBoxLayout(this);
   QLabel *label = new QLabel(mLabel, this);
-  l->add(label);
+  l->addWidget(label);
   mEdit = new QLineEdit(this);
   connect(mEdit, SIGNAL(textChanged(const QString &)), SLOT(textChanged(const QString &)));
-  l->add(mEdit);
+  l->addWidget(mEdit);
 }
 
 KXSLineEditControl::KXSLineEditControl(QWidget *parent, const QString &name,
                                   const QXmlAttributes &attr )
   : QWidget(parent), KXSStringItem(name, attr)
 {
+  // NOTE: Contexts used and assembled here have to match with contexts
+  // extracted by the PO template creation script.
+
   QVBoxLayout *l = new QVBoxLayout(this);
-  QLabel *label = new QLabel(i18n(mLabel.toUtf8()), this);
-  l->add(label);
+  QLabel *label = new QLabel(i18nc("@label:textbox", mLabel.toUtf8()), this);
+  l->addWidget(label);
   mEdit = new QLineEdit(this);
   connect(mEdit, SIGNAL(textChanged(const QString &)), SLOT(textChanged(const QString &)));
-  l->add(mEdit);
+  l->addWidget(mEdit);
 }
 
 void KXSLineEditControl::textChanged( const QString &text )
 {
-  mValue = text;
-  emit changed();
+    mValue = text;
+    emit changed();
 }
 
 void KXSLineEditControl::read(KConfig &config)
@@ -278,23 +324,27 @@ KXSFileControl::KXSFileControl(QWidget *parent, const QString &name,
 {
   QVBoxLayout *l = new QVBoxLayout(this);
   QLabel *label = new QLabel(mLabel, this);
-  l->add(label);
+  l->addWidget(label);
   mEdit = new QLineEdit(this);
   connect(mEdit, SIGNAL(textChanged(const QString &)), SLOT(textChanged(const QString &)));
-  l->add(mEdit);
+  l->addWidget(mEdit);
 }
 
 KXSFileControl::KXSFileControl(QWidget *parent, const QString &name,
                                   const QXmlAttributes &attr )
   : QWidget(parent), KXSStringItem(name, attr)
 {
+  // NOTE: Contexts used and assembled here have to match with contexts
+  // extracted by the PO template creation script.
+
   QVBoxLayout *l = new QVBoxLayout(this);
-  QLabel *label = new QLabel(i18n(mLabel.toUtf8()), this);
-  l->add(label);
-  QHBoxLayout *hb = new QHBoxLayout(l);
+  QLabel *label = new QLabel(i18nc("@label:chooser", mLabel.toUtf8()), this);
+  l->addWidget(label);
+  QHBoxLayout *hb = new QHBoxLayout();
+  l->addLayout(hb);
   mEdit = new QLineEdit(this);
   connect(mEdit, SIGNAL(textChanged(const QString &)), SLOT(textChanged(const QString &)));
-  hb->add(mEdit);
+  hb->addWidget(mEdit);
   QPushButton *pb = new QPushButton( "...", this );
   connect( pb, SIGNAL(clicked()), this, SLOT(selectFile()) );
   hb->addWidget(pb);
@@ -302,8 +352,8 @@ KXSFileControl::KXSFileControl(QWidget *parent, const QString &name,
 
 void KXSFileControl::textChanged( const QString &text )
 {
-  mValue = text;
-  emit changed();
+    mValue = text;
+    emit changed();
 }
 
 void KXSFileControl::selectFile()
