@@ -16,8 +16,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
-  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 // for enable-final
@@ -28,8 +28,8 @@
 #include <qimage.h>
 #include <qpixmap.h>
 #include <qpainter.h>
-#include <qptrlist.h>
-
+#include <q3ptrlist.h>
+#include <kcommondecoration.h>
 #include <kdecoration.h>
 
 // #include <ksimpleconfig.h>
